==> byteplus_rtc-3.44.1.tar.gz: lib/api/bytertc_video_event_handler.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import '../src/bytertc_video_event_impl.dart';
import 'bytertc_event_define.dart';

/// RTCVideo event callback
class RTCVideoEventHandler with RTCVideoEventValue {
  /// Callbacks when warning occurs.
  ///
  /// This callback indicates that a (network or media-related) warning has occurred while the SDK is running. Normally, the warning message can be ignored and the SDK will automatically recover.
  OnWarningType? onWarning;

  /// Callbacks when error occurs.
  ///
  /// This callback is triggered when a network or media related error occurs while the SDK is running and cannot be automatically recovered.
  OnErrorType? onError;

  /// Callback for failed room creation.
  OnCreateRoomStateChangedType? onCreateRoomStateChanged;

  /// This callback is triggered when the status of the network connection between the SDK and the RTC server changes.
  OnConnectionStateChanged? onConnectionStateChanged;

  /// This callback is triggered when the client's network connection type has changed.
  OnNetworkTypeChangedType? onNetworkTypeChanged;

  /// When a user calls [RTCVideo.startAudioCapture] to turn on the device for audio capture, others in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStartAudioCapture;

  /// When a user calls [RTCVideo.stopAudioCapture] to turn off audio capture, others in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStopAudioCapture;

  /// The local user will receive this callback when the first local audio frame is captured.
  OnFirstLocalAudioFrameType? onFirstLocalAudioFrame;

  /// The local user will receive this callback after receiving the first remote audio frame.
  OnFirstRemoteAudioFrameType? onFirstRemoteAudioFrame;

  /// The local user will receive this callback periodically after calling [RTCVideo.enableAudioPropertiesReport] to get the volume information for the local microphone and screen capture.
  OnLocalAudioPropertiesReportType? onLocalAudioPropertiesReport;

  /// After calling [RTCVideo.enableAudioPropertiesReport], the local user will receive this callback periodically to get the volume information of the remote audio.
  ///
  /// Audio of remote users includes microphone audio and screen audio captured using the RTC SDK's internal capture module.
  OnRemoteAudioPropertiesReportType? onRemoteAudioPropertiesReport;

  /// After calling [RTCVideo.enableAudioPropertiesReport], the local user will receive this callback periodically to get information about the most active user in the room.
  OnActiveSpeakerType? onActiveSpeaker;

  /// When a user calls [RTCVideo.startVideoCapture] to start video capture, other users in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStartVideoCapture;

  /// When a user calls [RTCVideo.startVideoCapture] to stop video capture, other users in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStopVideoCapture;

  /// This callback is triggered when the first locally captured video/screen share screen is rendered in the local view.
  OnFirstLocalVideoFrameCapturedType? onFirstLocalVideoFrameCaptured;

  /// This callback is triggered after the first frame of remote video stream is locally rendered by SDK.
  OnFirstRemoteVideoFrameRenderedType? onFirstRemoteVideoFrameRendered;

  /// This callback after the first frame of remote video stream is received and decoded by SDK.
  OnFirstRemoteVideoFrameRenderedType? onFirstRemoteVideoFrameDecoded;

  /// Users in the room who subscribe to the video stream receive this callback when the remote video size or rotation information changes.
  OnRemoteVideoSizeChangedType? onRemoteVideoSizeChanged;

  /// This callback when local video size or rotation information changes.
  OnLocalVideoSizeChangedType? onLocalVideoSizeChanged;

  /// Audio device state callback, returns the state of audio capture and audio playback devices.
  OnAudioDeviceStateChangedType? onAudioDeviceStateChanged;

  /// Video device state callback, returns the state of camera capture and screen capture devices.
  OnVideoDeviceStateChangedType? onVideoDeviceStateChanged;

  /// Audio device warning callback. The audio devices includes audio capture devices and audio rendering devices.
  OnAudioDeviceWarningType? onAudioDeviceWarning;

  /// Video device warning callback. The video devices includes video capture devices.
  OnVideoDeviceWarningType? onVideoDeviceWarning;

  /// Callback on first audio frame send status change.
  OnMediaFrameSendStateChangedType? onAudioFrameSendStateChanged;

  /// Callback on first video frame send status change.
  OnMediaFrameSendStateChangedType? onVideoFrameSendStateChanged;

  /// Callback on first screen frame send status change.
  OnMediaFrameSendStateChangedType? onScreenVideoFrameSendStateChanged;

  /// Callback on first audio frame playback status change.
  OnMediaFramePlayStateChangedType? onAudioFramePlayStateChanged;

  /// Callback on first video frame playback status change.
  OnMediaFramePlayStateChangedType? onVideoFramePlayStateChanged;

  /// Callback on first screen frame playback status change.
  OnMediaFramePlayStateChangedType? onScreenVideoFramePlayStateChanged;

  /// This callback is triggered when the audio playback route changes.
  ///
  /// Either of the following action will lead to audio route switching:
  /// + Connecting/Disconnecting an audio device.
  /// + Designating the other audio device by calling [RTCVideo.setAudioRoute].<br>
  /// See [Set the Audio Route](https://docs.byteplus.com/byteplus-rtc/docs/117836) for details.
  OnAudioRouteChangedType? onAudioRouteChanged;

  /// The user receives this callback after receiving a video frame with a SEI message.
  OnSEIMessageReceivedType? onSEIMessageReceived;

  /// Callback about publishing status of the black frame video stream.
  ///
  /// In a voice call scenario, when the local user calls [RTCVideo.sendSEIMessage] to send SEI data with a black frame, the sending status of the stream is notified to the remote user through this callback.<br>
  /// You can tell from this callback that the video frame carrying SEI data is a black frame and thus not render that video frame.
  OnSEIStreamUpdateType? onSEIStreamUpdate;

  /// The user receives this callback after receiving an audio stream sync message from the remote user calling [RTCVideo.sendStreamSyncInfo].
  OnStreamSyncInfoReceivedType? onStreamSyncInfoReceived;

  /// This callback is triggered periodically (2s) reporting the current CPU and memory usage.
  OnSysStatsType? get onSysStats;
  set onSysStats(OnSysStatsType? onSysStats);

  /// The local user receives this callback when the audio state changes.
  OnLocalAudioStateChangedType? onLocalAudioStateChanged;

  /// The user receives this callback when the state of the audio stream from the remote end changes.
  OnRemoteAudioStateChangedType? onRemoteAudioStateChanged;

  /// he local user receives this callback when the video state changes.
  OnLocalVideoStateChangedType? onLocalVideoStateChanged;

  /// When the state of the remote video stream changes, users in the room subscribed to this stream receive this callback.
  OnRemoteVideoStateChangedType? onRemoteVideoStateChanged;

  /// The user receives this callback after calling [RTCVideo.login].
  OnLoginResultType? onLoginResult;

  /// The user receives this callback after calling [RTCVideo.logout].
  EmptyCallbackType? onLogout;

  /// The user receives this callback after calling [RTCVideo.setServerParams].
  OnServerParamsSetResultType? onServerParamsSetResult;

  /// The user receives this callback after calling [RTCVideo.getPeerOnlineStatus].
  OnGetPeerOnlineStatusType? onGetPeerOnlineStatus;

  /// Local users will receive this callback when they receive a text message from a user outside the room calling [RTCVideo.sendUserMessageOutsideRoom].
  OnMessageReceivedType? onUserMessageReceivedOutsideRoom;

  /// Local users will receive this callback when they receive a binary message from a user outside the room calling [RTCVideo.sendUserBinaryMessageOutsideRoom].
  OnBinaryMessageReceivedType? onUserBinaryMessageReceivedOutsideRoom;

  /// Callback for sending a message to a specified user outside the room.
  OnMessageSendResultType? onUserMessageSendResultOutsideRoom;

  /// This callback is received after the user calls [RTCVideo.sendServerMessage] or [RTCVideo.sendServerBinaryMessage] to send a message.
  OnServerMessageSendResultType? onServerMessageSendResult;

  /// Callbakc of pre-call network detection result.
  ///
  /// After [RTCVideo.startNetworkDetection] is successfully called, the user will receive this callback in 3s for the first time and every 2s thereafter.
  OnNetworkDetectionResultType? onNetworkDetectionResult;

  /// Callback for end of pre-call network detection.
  ///
  /// The following will stop detection and trigger this callback once:
  /// + Call [RTCVideo.stopNetworkDetection] to stop network detection.
  /// + The first frame of remote/local audio is received.
  /// + The detection lasts more than 3 mins.
  /// + The entire detection link is disconnected for a certain period of time.
  OnNetworkDetectionStoppedType? onNetworkDetectionStopped;

  /// Callback when audio file playback status changes in audio mixing
  ///
  /// The timing at which this callback will be triggered is as follows:
  /// + When [RTCVideo.startAudioMixing] is successfully called.
  /// + When calling [RTCVideo.startAudioMixing] repeatedly with the same ID.
  /// + When calling [RTCVideo.pauseAudioMixing] to pause audio mixing.
  /// + When calling [RTCVideo.resumeAudioMixing] to resume audio mixing.
  /// + When calling [RTCVideo.stopAudioMixing] to stop audio mixing.
  /// + When playback ends.
  OnAudioMixingStateChangedType? onAudioMixingStateChanged;

  /// Callback for playback progress of mixed audio files.
  ///
  /// After calling [RTCAudioMixingManager.setAudioMixingProgressInterval] to set the time interval to a value greater than 0, or calling [RTCAudioMixingManager.startAudioMixing] to set the time interval in `config` to a value greater than 0, the SDK will trigger the callback according to the set time interval.
  OnAudioMixingPlayingProgressType? onAudioMixingPlayingProgress;

  /// This callback is triggered:<br>
  /// + When insufficient device performance is detected without publishing performance fallback enabled.
  /// + When publishing performance falls back/restores due to device performance/network reasons after publishing performance fallback is turned on.
  OnPerformanceAlarmsType? onPerformanceAlarms;

  /// Once the fallback option is set, fallback or reverting from a Fallback of a media stream will trigger this callback.
  OnSimulcastSubscribeFallbackType? onSimulcastSubscribeFallback;

  /// This callback is triggered when the HTTP proxy connection status changes.
  OnHttpProxyStateType? onHttpProxyState;

  /// This callback is triggered when the HTTPS proxy connection status changes.
  OnHttpsProxyStateType? onHttpsProxyState;

  /// This callback is triggered when the Socks5 proxy connection status changes.
  OnSocks5ProxyStateType? onSocks5ProxyState;

  /// The user will receive this callback after calling [RTCVideo.startFileRecording] or [RTCVideo.stopFileRecording].
  OnRecordingStateUpdateType? onRecordingStateUpdate;

  /// This callback is triggered every second after [RTCVideo.startFileRecording] is called for local recording.
  OnRecordingProgressUpdateType? onRecordingProgressUpdate;

  /// Callback of the result of publishing the public stream.
  ///
  /// After [RTCVideo.startPushPublicStream] is called to publish a public stream, the start result is notified to the user via this callback.
  OnPushPublicStreamResultType? onPushPublicStreamResult;

  /// Callback of the result of the subscription to the public stream.
  ///
  /// After [RTCVideo.startPlayPublicStream] is called to start subscribing to the public stream, the user will receive the start result and the error during the subscription through this callback.
  OnPlayPublicStreamResultType? onPlayPublicStreamResult;

  /// Callback of the SEI carried by the public video stream.
  ///
  /// After [RTCVideo.startPlayPublicStream] is called to start subscribing to the public stream, the SEI messages in the public stream are received via this callback.
  ///
  /// You should note that when multiple video streams in a public stream all contain SEI information,
  /// + SEI messages will be sent separately via multiple callbacks when they do not conflict with each other.
  /// + When SEI messages conflict on the same frame, the SEI from only one stream is passed through and merged into the common stream.
  OnPublicStreamSEIMessageReceivedType? onPublicStreamSEIMessageReceived;

  /// Callback for successful decoding of the first video frame of a public stream.
  OnFirstPublicStreamVideoFrameDecodedType?
      onFirstPublicStreamVideoFrameDecoded;

  /// Callback for successful decoding of the first audio frame of a public stream.
  OnFirstPublicStreamAudioFrameType? onFirstPublicStreamAudioFrame;

  /// After calling [RTCVideo.startCloudProxy] to enable the cloud proxy, this event is called back when the SDK successfully connects to the cloud proxy server for the first time.
  OnCloudProxyConnectedType? onCloudProxyConnected;

  /// Callback about the call test result.
  ///
  /// The timing when this callback will be triggered is as follows:
  /// + A device-related error occured during the test.
  /// + After a successful test.
  /// + After stopping the test, provided that the audio/video playback was not received during the test due to non-device reasons.
  OnEchoTestResultType? onEchoTestResult;

  RTCVideoEventHandler({
    this.onWarning,
    this.onError,
    this.onCreateRoomStateChanged,
    this.onConnectionStateChanged,
    this.onNetworkTypeChanged,
    this.onUserStartAudioCapture,
    this.onUserStopAudioCapture,
    this.onFirstLocalAudioFrame,
    this.onFirstRemoteAudioFrame,
    this.onLocalAudioPropertiesReport,
    this.onRemoteAudioPropertiesReport,
    this.onActiveSpeaker,
    this.onUserStartVideoCapture,
    this.onUserStopVideoCapture,
    this.onFirstLocalVideoFrameCaptured,
    this.onFirstRemoteVideoFrameRendered,
    this.onFirstRemoteVideoFrameDecoded,
    this.onRemoteVideoSizeChanged,
    this.onLocalVideoSizeChanged,
    this.onAudioDeviceStateChanged,
    this.onVideoDeviceStateChanged,
    this.onAudioDeviceWarning,
    this.onVideoDeviceWarning,
    this.onAudioFrameSendStateChanged,
    this.onVideoFrameSendStateChanged,
    this.onScreenVideoFrameSendStateChanged,
    this.onAudioFramePlayStateChanged,
    this.onVideoFramePlayStateChanged,
    this.onScreenVideoFramePlayStateChanged,
    this.onAudioRouteChanged,
    this.onSEIMessageReceived,
    this.onSEIStreamUpdate,
    this.onStreamSyncInfoReceived,
    OnSysStatsType? onSysStats,
    this.onLocalAudioStateChanged,
    this.onRemoteAudioStateChanged,
    this.onLocalVideoStateChanged,
    this.onRemoteVideoStateChanged,
    this.onLoginResult,
    this.onLogout,
    this.onServerParamsSetResult,
    this.onGetPeerOnlineStatus,
    this.onUserMessageReceivedOutsideRoom,
    this.onUserBinaryMessageReceivedOutsideRoom,
    this.onUserMessageSendResultOutsideRoom,
    this.onServerMessageSendResult,
    this.onNetworkDetectionResult,
    this.onNetworkDetectionStopped,
    this.onAudioMixingStateChanged,
    this.onAudioMixingPlayingProgress,
    this.onPerformanceAlarms,
    this.onSimulcastSubscribeFallback,
    this.onHttpProxyState,
    this.onHttpsProxyState,
    this.onSocks5ProxyState,
    this.onRecordingStateUpdate,
    this.onRecordingProgressUpdate,
    this.onPushPublicStreamResult,
    this.onPlayPublicStreamResult,
    this.onPublicStreamSEIMessageReceived,
    this.onFirstPublicStreamVideoFrameDecoded,
    this.onFirstPublicStreamAudioFrame,
    this.onCloudProxyConnected,
    this.onEchoTestResult,
  }) {
    this.onSysStats = onSysStats;
  }
}

==> byteplus_rtc-3.45.1.tar.gz: lib/api/bytertc_video_event_handler.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import '../src/bytertc_video_event_impl.dart';
import 'bytertc_event_define.dart';

/// RTCVideo event callback
class RTCVideoEventHandler extends RTCVideoEventValue {
  /// Callbacks when warning occurs.
  ///
  /// This callback indicates that a (network or media-related) warning has occurred while the SDK is running. Normally, the warning message can be ignored and the SDK will automatically recover.
  OnWarningType? onWarning;

  /// Callbacks when error occurs.
  ///
  /// This callback is triggered when a network or media related error occurs while the SDK is running and cannot be automatically recovered.
  OnErrorType? onError;

  /// Callback for failed room creation.
  OnCreateRoomStateChangedType? onCreateRoomStateChanged;

  /// This callback is triggered when the status of the network connection between the SDK and the RTC server changes.
  OnConnectionStateChanged? onConnectionStateChanged;

  /// This callback is triggered when the client's network connection type has changed.
  OnNetworkTypeChangedType? onNetworkTypeChanged;

  /// When a user calls [RTCVideo.startAudioCapture] to turn on the device for audio capture, others in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStartAudioCapture;

  /// When a user calls [RTCVideo.stopAudioCapture] to turn off audio capture, others in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStopAudioCapture;

  /// The local user will receive this callback when the first local audio frame is captured.
  OnFirstLocalAudioFrameType? onFirstLocalAudioFrame;

  /// The local user will receive this callback after receiving the first remote audio frame.
  OnFirstRemoteAudioFrameType? onFirstRemoteAudioFrame;

  /// The local user will receive this callback periodically after calling [RTCVideo.enableAudioPropertiesReport] to get the volume information for the local microphone and screen capture.
  OnLocalAudioPropertiesReportType? onLocalAudioPropertiesReport;

  /// After calling [RTCVideo.enableAudioPropertiesReport], the local user will receive this callback periodically to get the volume information of the remote audio.
  ///
  /// Audio of remote users includes microphone audio and screen audio captured using the RTC SDK's internal capture module.
  OnRemoteAudioPropertiesReportType? onRemoteAudioPropertiesReport;

  /// After calling [RTCVideo.enableAudioPropertiesReport], the local user will receive this callback periodically to get information about the most active user in the room.
  OnActiveSpeakerType? onActiveSpeaker;

  /// When a user calls [RTCVideo.startVideoCapture] to start video capture, other users in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStartVideoCapture;

  /// When a user calls [RTCVideo.startVideoCapture] to stop video capture, other users in the room will receive this callback.
  OnUserOperateMediaCaptureType? onUserStopVideoCapture;

  /// This callback is triggered when the first locally captured video/screen share screen is rendered in the local view.
  OnFirstLocalVideoFrameCapturedType? onFirstLocalVideoFrameCaptured;

  /// This callback is triggered after the first frame of remote video stream is locally rendered by SDK.
  OnFirstRemoteVideoFrameRenderedType? onFirstRemoteVideoFrameRendered;

  /// This callback after the first frame of remote video stream is received and decoded by SDK.
  OnFirstRemoteVideoFrameRenderedType? onFirstRemoteVideoFrameDecoded;

  /// Users in the room who subscribe to the video stream receive this callback when the remote video size or rotation information changes.
  OnRemoteVideoSizeChangedType? onRemoteVideoSizeChanged;

  /// This callback when local video size or rotation information changes.
  OnLocalVideoSizeChangedType? onLocalVideoSizeChanged;

  /// Audio device state callback, returns the state of audio capture and audio playback devices.
  OnAudioDeviceStateChangedType? onAudioDeviceStateChanged;

  /// Video device state callback, returns the state of camera capture and screen capture devices.
  OnVideoDeviceStateChangedType? onVideoDeviceStateChanged;

  /// Audio device warning callback. The audio devices includes audio capture devices and audio rendering devices.
  OnAudioDeviceWarningType? onAudioDeviceWarning;

  /// Video device warning callback. The video devices includes video capture devices.
  OnVideoDeviceWarningType? onVideoDeviceWarning;

  /// Callback on first audio frame send status change.
  OnMediaFrameSendStateChangedType? onAudioFrameSendStateChanged;

  /// Callback on first video frame send status change.
  OnMediaFrameSendStateChangedType? onVideoFrameSendStateChanged;

  /// Callback on first screen frame send status change.
  OnMediaFrameSendStateChangedType? onScreenVideoFrameSendStateChanged;

  /// Callback on first audio frame playback status change.
  OnMediaFramePlayStateChangedType? onAudioFramePlayStateChanged;

  /// Callback on first video frame playback status change.
  OnMediaFramePlayStateChangedType? onVideoFramePlayStateChanged;

  /// Callback on first screen frame playback status change.
  OnMediaFramePlayStateChangedType? onScreenVideoFramePlayStateChanged;

  /// This callback is triggered when the audio playback route changes.
  ///
  /// Either of the following action will lead to audio route switching:
  /// + Connecting/Disconnecting an audio device.
  /// + Designating the other audio device by calling [RTCVideo.setAudioRoute].<br>
  /// See [Set the Audio Route](https://docs.byteplus.com/byteplus-rtc/docs/117836) for details.
  OnAudioRouteChangedType? onAudioRouteChanged;

  /// The user receives this callback after receiving a video frame with a SEI message.
  OnSEIMessageReceivedType? onSEIMessageReceived;

  /// Callback about publishing status of the black frame video stream.
  ///
  /// In a voice call scenario, when the local user calls [RTCVideo.sendSEIMessage] to send SEI data with a black frame, the sending status of the stream is notified to the remote user through this callback.<br>
  /// You can tell from this callback that the video frame carrying SEI data is a black frame and thus not render that video frame.
  OnSEIStreamUpdateType? onSEIStreamUpdate;

  /// The user receives this callback after receiving an audio stream sync message from the remote user calling [RTCVideo.sendStreamSyncInfo].
  OnStreamSyncInfoReceivedType? onStreamSyncInfoReceived;

  /// This callback is triggered periodically (2s) reporting the current CPU and memory usage.
  abstract OnSysStatsType? onSysStats;

  /// The local user receives this callback when the audio state changes.
  OnLocalAudioStateChangedType? onLocalAudioStateChanged;

  /// The user receives this callback when the state of the audio stream from the remote end changes.
  OnRemoteAudioStateChangedType? onRemoteAudioStateChanged;

  /// he local user receives this callback when the video state changes.
  OnLocalVideoStateChangedType? onLocalVideoStateChanged;

  /// When the state of the remote video stream changes, users in the room subscribed to this stream receive this callback.
  OnRemoteVideoStateChangedType? onRemoteVideoStateChanged;

  /// The user receives this callback after calling [RTCVideo.login].
  OnLoginResultType? onLoginResult;

  /// The user receives this callback after calling [RTCVideo.logout].
  EmptyCallbackType? onLogout;

  /// The user receives this callback after calling [RTCVideo.setServerParams].
  OnServerParamsSetResultType? onServerParamsSetResult;

  /// The user receives this callback after calling [RTCVideo.getPeerOnlineStatus].
  OnGetPeerOnlineStatusType? onGetPeerOnlineStatus;

  /// Local users will receive this callback when they receive a text message from a user outside the room calling [RTCVideo.sendUserMessageOutsideRoom].
  OnMessageReceivedType? onUserMessageReceivedOutsideRoom;

  /// Local users will receive this callback when they receive a binary message from a user outside the room calling [RTCVideo.sendUserBinaryMessageOutsideRoom].
  OnBinaryMessageReceivedType? onUserBinaryMessageReceivedOutsideRoom;

  /// Callback for sending a message to a specified user outside the room.
  OnMessageSendResultType? onUserMessageSendResultOutsideRoom;

  /// This callback is received after the user calls [RTCVideo.sendServerMessage] or [RTCVideo.sendServerBinaryMessage] to send a message.
  OnServerMessageSendResultType? onServerMessageSendResult;

  /// Callbakc of pre-call network detection result.
  ///
  /// After [RTCVideo.startNetworkDetection] is successfully called, the user will receive this callback in 3s for the first time and every 2s thereafter.
  OnNetworkDetectionResultType? onNetworkDetectionResult;

  /// Callback for end of pre-call network detection.
  ///
  /// The following will stop detection and trigger this callback once:
  /// + Call [RTCVideo.stopNetworkDetection] to stop network detection.
  /// + The first frame of remote/local audio is received.
  /// + The detection lasts more than 3 mins.
  /// + The entire detection link is disconnected for a certain period of time.
  OnNetworkDetectionStoppedType? onNetworkDetectionStopped;

  /// Callback when audio file playback status changes in audio mixing
  ///
  /// The timing at which this callback will be triggered is as follows:
  /// + When [RTCVideo.startAudioMixing] is successfully called.
  /// + When calling [RTCVideo.startAudioMixing] repeatedly with the same ID.
  /// + When calling [RTCVideo.pauseAudioMixing] to pause audio mixing.
  /// + When calling [RTCVideo.resumeAudioMixing] to resume audio mixing.
  /// + When calling [RTCVideo.stopAudioMixing] to stop audio mixing.
  /// + When playback ends.
  OnAudioMixingStateChangedType? onAudioMixingStateChanged;

  /// Callback for playback progress of mixed audio files.
  ///
  /// After calling [RTCAudioMixingManager.setAudioMixingProgressInterval] to set the time interval to a value greater than 0, or calling [RTCAudioMixingManager.startAudioMixing] to set the time interval in `config` to a value greater than 0, the SDK will trigger the callback according to the set time interval.
  OnAudioMixingPlayingProgressType? onAudioMixingPlayingProgress;

  /// This callback is triggered:<br>
  /// + When insufficient device performance is detected without publishing performance fallback enabled.
  /// + When publishing performance falls back/restores due to device performance/network reasons after publishing performance fallback is turned on.
  OnPerformanceAlarmsType? onPerformanceAlarms;

  /// Once the fallback option is set, fallback or reverting from a Fallback of a media stream will trigger this callback.
  OnSimulcastSubscribeFallbackType? onSimulcastSubscribeFallback;

  /// This callback is triggered when the HTTP proxy connection status changes.
  OnHttpProxyStateType? onHttpProxyState;

  /// This callback is triggered when the HTTPS proxy connection status changes.
  OnHttpsProxyStateType? onHttpsProxyState;

  /// This callback is triggered when the Socks5 proxy connection status changes.
  OnSocks5ProxyStateType? onSocks5ProxyState;

  /// The user will receive this callback after calling [RTCVideo.startFileRecording] or [RTCVideo.stopFileRecording].
  OnRecordingStateUpdateType? onRecordingStateUpdate;

  /// This callback is triggered every second after [RTCVideo.startFileRecording] is called for local recording.
  OnRecordingProgressUpdateType? onRecordingProgressUpdate;

  /// Callback of the result of publishing the public stream.
  ///
  /// After [RTCVideo.startPushPublicStream] is called to publish a public stream, the start result is notified to the user via this callback.
  OnPushPublicStreamResultType? onPushPublicStreamResult;

  /// Callback of the result of the subscription to the public stream.
  ///
  /// After [RTCVideo.startPlayPublicStream] is called to start subscribing to the public stream, the user will receive the start result and the error during the subscription through this callback.
  OnPlayPublicStreamResultType? onPlayPublicStreamResult;

  /// Callback of the SEI carried by the public video stream.
  ///
  /// After [RTCVideo.startPlayPublicStream] is called to start subscribing to the public stream, the SEI messages in the public stream are received via this callback.
  ///
  /// You should note that when multiple video streams in a public stream all contain SEI information,
  /// + SEI messages will be sent separately via multiple callbacks when they do not conflict with each other.
  /// + When SEI messages conflict on the same frame, the SEI from only one stream is passed through and merged into the common stream.
  OnPublicStreamSEIMessageReceivedType? onPublicStreamSEIMessageReceived;

  /// Callback for successful decoding of the first video frame of a public stream.
  OnFirstPublicStreamVideoFrameDecodedType?
      onFirstPublicStreamVideoFrameDecoded;

  /// Callback for successful decoding of the first audio frame of a public stream.
  OnFirstPublicStreamAudioFrameType? onFirstPublicStreamAudioFrame;

  /// After calling [RTCVideo.startCloudProxy] to enable the cloud proxy, this event is called back when the SDK successfully connects to the cloud proxy server for the first time.
  OnCloudProxyConnectedType? onCloudProxyConnected;

  /// Callback about the call test result.
  ///
  /// The timing when this callback will be triggered is as follows:
  /// + A device-related error occured during the test.
  /// + After a successful test.
  /// + After stopping the test, provided that the audio/video playback was not received during the test due to non-device reasons.
  OnEchoTestResultType? onEchoTestResult;

  RTCVideoEventHandler({
    this.onWarning,
    this.onError,
    this.onCreateRoomStateChanged,
    this.onConnectionStateChanged,
    this.onNetworkTypeChanged,
    this.onUserStartAudioCapture,
    this.onUserStopAudioCapture,
    this.onFirstLocalAudioFrame,
    this.onFirstRemoteAudioFrame,
    this.onLocalAudioPropertiesReport,
    this.onRemoteAudioPropertiesReport,
    this.onActiveSpeaker,
    this.onUserStartVideoCapture,
    this.onUserStopVideoCapture,
    this.onFirstLocalVideoFrameCaptured,
    this.onFirstRemoteVideoFrameRendered,
    this.onFirstRemoteVideoFrameDecoded,
    this.onRemoteVideoSizeChanged,
    this.onLocalVideoSizeChanged,
    this.onAudioDeviceStateChanged,
    this.onVideoDeviceStateChanged,
    this.onAudioDeviceWarning,
    this.onVideoDeviceWarning,
    this.onAudioFrameSendStateChanged,
    this.onVideoFrameSendStateChanged,
    this.onScreenVideoFrameSendStateChanged,
    this.onAudioFramePlayStateChanged,
    this.onVideoFramePlayStateChanged,
    this.onScreenVideoFramePlayStateChanged,
    this.onAudioRouteChanged,
    this.onSEIMessageReceived,
    this.onSEIStreamUpdate,
    this.onStreamSyncInfoReceived,
    OnSysStatsType? onSysStats,
    this.onLocalAudioStateChanged,
    this.onRemoteAudioStateChanged,
    this.onLocalVideoStateChanged,
    this.onRemoteVideoStateChanged,
    this.onLoginResult,
    this.onLogout,
    this.onServerParamsSetResult,
    this.onGetPeerOnlineStatus,
    this.onUserMessageReceivedOutsideRoom,
    this.onUserBinaryMessageReceivedOutsideRoom,
    this.onUserMessageSendResultOutsideRoom,
    this.onServerMessageSendResult,
    this.onNetworkDetectionResult,
    this.onNetworkDetectionStopped,
    this.onAudioMixingStateChanged,
    this.onAudioMixingPlayingProgress,
    this.onPerformanceAlarms,
    this.onSimulcastSubscribeFallback,
    this.onHttpProxyState,
    this.onHttpsProxyState,
    this.onSocks5ProxyState,
    this.onRecordingStateUpdate,
    this.onRecordingProgressUpdate,
    this.onPushPublicStreamResult,
    this.onPlayPublicStreamResult,
    this.onPublicStreamSEIMessageReceived,
    this.onFirstPublicStreamVideoFrameDecoded,
    this.onFirstPublicStreamAudioFrame,
    this.onCloudProxyConnected,
    this.onEchoTestResult,
  }) {
    this.onSysStats = onSysStats;
  }
}
